from setuptools import setup

setup(
    name='lmLib',
    version='0.0.0',
    description='Model Based Signal Processing Library',
    long_description='',
    url='https://www.lmlib.ch',
    author='Reto Wildhaber, Frédéric Waldmann',
    author_email='frederic.waldmann@gmail.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning']
)